<?php
/**
 * Mdulo Correios para Zen Cart v1.3.x
 * Desenvolvido por Diego Vieira - diego@customscriptz.com
 * https://customscriptz.com
 * Se desejar, distribua gratuitamente, porm no remova os crditos.
 *
 * @package shippingMethod
 * @copyright Copyright 2003-2010 Zen Cart Development Team
 * @copyright Portions Copyright 2003 osCommerce
 * @license http://www.zen-cart.com/license/2_0.txt GNU Public License V2.0
 */

$copyright = 'Desenvolvido por Ian Garcez, adpatado do mdulo de Diego Vieira - <a href="http://customscriptz.com/support" target="_blank">diego@customscriptz.com</a><br /><a href="https://customscriptz.com" target="_blank">https://customscriptz.com</a><br /><br />
Este mdulo de frete pode ser distribudo gratuitamente desde que estes crditos sejam mantidos.<br /><br />
Nenhum suporte  dado para a verso gratuita, apenas correes de bugs podero ser reportadas. <em>Use por usa conta e risco.</em><br /><br />
Efetue testes afim de verificar se o mdulo est funcionando corretamente e se as taxas calculadas so as mesmas que a praticadas no site e agncias do correio.<br /><br />';

/**
 * Correios Shipping Module class
 *
 */
class pac extends base {
  /**
   * Declare shipping module alias code
   *
   * @var string
   */
  var $code;
  /**
   * Shipping module display name
   *
   * @var string
   */
  var $title;
  /**
   * Shipping module display description
   *
   * @var string
   */
  var $description;
  /**
   * Shipping module icon filename/path
   *
   * @var string
   */
  var $icon;
  /**
   * Shipping module status
   *
   * @var boolean
   */
  var $enabled;
  /**
   * Constructor
   *
   * @return correios
   */

  function pac() {
    global $order, $db, $template, $current_page_base, $copyright;

    $this->code = 'pac';
    $this->title = MODULE_SHIPPING_PAC_TEXT_TITLE;
    $this->description = $copyright.MODULE_SHIPPING_PAC_TEXT_DESCRIPTION; 
    $this->sort_order = MODULE_SHIPPING_PAC_SORT_ORDER;
    $this->icon = $template->get_template_dir('correios_pac.png', DIR_WS_TEMPLATE, $current_page_base,'images/icons'). '/' . 'correios_pac.png';

    // disable only when entire cart is free shipping
    if (zen_get_shipping_enabled($this->code)) {
      $this->enabled = ((MODULE_SHIPPING_PAC_STATUS == 'True') ? true : false);
    }

    if ( ($this->enabled == true) && ((int)MODULE_SHIPPING_PAC_ZONE > 0) ) {
      $check_flag = false;
      $check = $db->Execute("select zone_id from " . TABLE_ZONES_TO_GEO_ZONES . " where geo_zone_id = '" . MODULE_SHIPPING_PAC_ZONE . "' and zone_country_id = '" . $order->delivery['country']['id'] . "' order by zone_id");
      while (!$check->EOF) {
        if ($check->fields['zone_id'] < 1) {
          $check_flag = true;
          break;
        } elseif ($check->fields['zone_id'] == $order->delivery['zone_id']) {
          $check_flag = true;
          break;
        }
        $check->MoveNext();
      }

      if ($check_flag == false) {
        $this->enabled = false;
      }
    }
  }

  /**
   * Get quote from shipping provider's API:
   *
   * @param string $method
   * @return array of quotation results
   */
  function quote($method = '') {
    global $order;

    $this->quotes = array('module' => $this->title,
                          'error' => sprintf(MODULE_SHIPPING_PAC_ERROR_NO_SHIPPING_AVAILABLE, $order->delivery['postcode']));
    
    $methods = $this->_calcularfrete();
    if (count($methods)>0)
    {
    	$this->quotes = array('id' => $this->code,
                              'module' => MODULE_SHIPPING_PAC_TEXT_TITLE,
                              'methods' => $methods);
    }
    
    if (zen_not_null($this->icon)) $this->quotes['icon'] = zen_image($this->icon, $this->title);

    return $this->quotes;
  }
  /**
   * check status of module
   *
   * @return boolean
   */
  function check() {
    global $db;
    if (!isset($this->_check)) {
      $check_query = $db->Execute("select configuration_value from " . TABLE_CONFIGURATION . " where configuration_key = 'MODULE_SHIPPING_PAC_STATUS'");
      $this->_check = $check_query->RecordCount();
    }
    return $this->_check;
  }
  /**
   * Install this module
   *
   */
  function install() {
    global $db;
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Modulo de Envio pelos Correios', 'MODULE_SHIPPING_PAC_STATUS', 'True', 'Voce gostaria de oferecer envio pelos correios?', '6', '0', 'zen_cfg_select_option(array(\'True\', \'False\'), ', now())");
    
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('CEP de Origem', 'MODULE_SHIPPING_PAC_CEP_ORIGEM', '".SHIPPING_ORIGIN_ZIP."', 'CEP de Origem sem hifen. Exemplo: 05311900', '6', '0', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Dias para Somar no Frete', 'MODULE_SHIPPING_PAC_DIAS_FRETE', '0', '1 (um) Dia ja e somado automaticamente por conta do dia de postagem dos correios.', '6', '0', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Servico Mao Propria', 'MODULE_SHIPPING_PAC_MAO_PROPRIA', 'Nao', 'As encomendas serao entregues com o servico adicional mao propria?<br /><strong>Isto ira alterar o valor do frete.</strong>', '6', '0', 'zen_cfg_select_option(array(\'Sim\', \'Nao\'), ', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Servico Aviso de Recebimento', 'MODULE_SHIPPING_PAC_AVISO_RECEBIMENTO', 'Nao', 'As encomendas serao entregues com o servico adicional aviso de recebimento?<br /><strong>Isto ira alterar o valor do frete.</strong>', '6', '0', 'zen_cfg_select_option(array(\'Sim\', \'Nao\'), ', now())");
    
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, use_function, set_function, date_added) values ('Zona de Envio', 'MODULE_SHIPPING_PAC_ZONE', '0', 'Se uma zona for selecionada, ira ativar esta forma de envio somente para essa zona.', '6', '0', 'zen_get_zone_class_title', 'zen_cfg_pull_down_zone_classes(', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, date_added) values ('Ordem', 'MODULE_SHIPPING_PAC_SORT_ORDER', '0', 'Ordem de amostragem.', '6', '0', now())");
    $db->Execute("insert into " . TABLE_CONFIGURATION . " (configuration_title, configuration_key, configuration_value, configuration_description, configuration_group_id, sort_order, set_function, date_added) values ('Modo Debug', 'MODULE_SHIPPING_PAC_DEBUG_MODE', 'Nao', 'Gostaria de ativar o modo de debug?<br />Ativando esta opcao serao enviados e-mails para o endereco de e-mail da configuracao da loja de acordo com a opcao selecionada', '6', '0', 'zen_cfg_select_option(array(\'Sim, todos os calculos\', \'Sim, somente erros\', \'Nao\'), ', now())");
  }
  /**
   * Remove this module
   *
   */
  function remove() {
    global $db;
    $db->Execute("delete from " . TABLE_CONFIGURATION . " where configuration_key like 'MODULE\_SHIPPING\_PAC\_%' ");
  }
  /**
   * Build array of keys used for installing/managing this module
   *
   * @return array
   */
  function keys() {
    $keys_list = array('MODULE_SHIPPING_PAC_STATUS', 'MODULE_SHIPPING_PAC_CEP_ORIGEM', 'MODULE_SHIPPING_PAC_DIAS_FRETE', 'MODULE_SHIPPING_PAC_MAO_PROPRIA', 'MODULE_SHIPPING_PAC_AVISO_RECEBIMENTO', 'MODULE_SHIPPING_PAC_ZONE', 'MODULE_SHIPPING_PAC_SORT_ORDER', 'MODULE_SHIPPING_PAC_DEBUG_MODE');
    return $keys_list;
  }
  
  function _calcularfrete() {
    global $order, $shipping_weight, $shipping_num_boxes;
    
	$url = 'http://ws.correios.com.br/calculador/CalcPrecoPrazo.asmx/CalcPrecoPrazo?nCdEmpresa={nCdEmpresa}&sDsSenha={sDsSenha}&nCdServico={nCdServico}&sCepOrigem={sCepOrigem}&sCepDestino={sCepDestino}&nVlPeso={nVlPeso}&nCdFormato={nCdFormato}&nVlComprimento={nVlComprimento}&nVlAltura={nVlAltura}&nVlLargura={nVlLargura}&nVlDiametro={nVlDiametro}&sCdMaoPropria={sCdMaoPropria}&nVlValorDeclarado={nVlValorDeclarado}&sCdAvisoRecebimento={sCdAvisoRecebimento}';
	$strings = array('{nCdEmpresa}',
					 '{sDsSenha}',
					 '{nCdServico}',
					 '{sCepOrigem}',
					 '{sCepDestino}',
					 '{nVlPeso}',
					 '{nCdFormato}',
					 '{nVlComprimento}',
					 '{nVlAltura}',
					 '{nVlLargura}',
					 '{nVlDiametro}',
					 '{sCdMaoPropria}',
					 '{nVlValorDeclarado}',
					 '{sCdAvisoRecebimento}');	
	
	$cep1 = array(',','.','-');
	$cep2 = array('','','');
	$cep = str_replace($cep1, $cep2, $order->delivery['postcode']);
	
	$replace = array(MODULE_SHIPPING_PAC_CODIGO_EMPRESA, //nCdEmpresa
					 MODULE_SHIPPING_PAC_SENHA_SERVICO, //sDsSenha
					 '41106', //nCdServico
					 MODULE_SHIPPING_PAC_CEP_ORIGEM, //sCepOrigem
					 $cep, //sCepDestino
					 $shipping_weight, //nVlPeso
					 '1', //nCdFormato
					 '16', //nVlComprimento
					 '16', //nVlAltura
					 '16', //nVlLargura
					 0, //nVlDiametro
					 (MODULE_SHIPPING_PAC_MAO_PROPRIA == 'Sim' ? 'S' : 'N'), //sCdMaoPropria
					 0, //nVlValorDeclarado
					 (MODULE_SHIPPING_PAC_AVISO_RECEBIMENTO == 'Sim' ? 'S' : 'N')); //sCdAvisoRecebimento
	
	$url = str_replace($strings, $replace, $url);
					 
	$ch = curl_init();
	curl_setopt($ch, CURLOPT_URL, $url);
	curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
	
	$result = curl_exec($ch);
	curl_close($ch);
	$xmlobj = simplexml_load_string($result);
	
	$methods = array();
    
  	$codigo		= (int)$xmlobj->Servicos->cServico->Codigo;
    $valor 		= str_replace(',','.',$xmlobj->Servicos->cServico->Valor);
    $prazo 		= ((int)$xmlobj->Servicos->cServico->PrazoEntrega + (int)MODULE_SHIPPING_PAC_DIAS_FRETE + 1);
    $erro 		= (int)$xmlobj->Servicos->cServico->Erro;
    $msgerro	= (string)$xmlobj->Servicos->cServico->MsgErro;
	
  	if ($erro == 0)
    {
    	$methods[] = array('id' => $codigo,
    				   	   'title' => 'PAC' . ($codigo_nao_informado ? sprintf(MODULE_SHIPPING_PAC_PRAZO_ENTREGA, $prazo) : ''),
    			           'cost' => $valor * $shipping_num_boxes);
    }

  	if ($erro > 0 && MODULE_SHIPPING_PAC_DEBUG_MODE != 'No')
    {
    	$email_subject = 'Falha no Mdulo de Frete dos Correios';
  		$email_text = date('d/m/y H:i:s').'
Voc est recebendo este e-mail, pois solicitou que todas as vezes que ocorresse um erro, o mesmo fosse enviado pra voc.
Para desativar, acesse o painel de administrao v at a opo de mdulos de frete e mude a opo debug para no.

[Dados do Cliente]
IP: ' . $_SESSION['customers_ip_address'] . '
ID: ' . $_SESSION['customer_id'] . '
Nome: ' . $_SESSION['customer_first_name'] . ' ' . $_SESSION['customer_last_name'] . '

[Dados de Entrega]
Nome: ' . $order->delivery['firstname'] . ' ' . $order->delivery['lastname'] . '
Empresa: ' . $order->delivery['company'] . '
Logradouro: ' . $order->delivery['street_address'] . '
Bairro: ' . $order->delivery['suburb'] . '
Cidade: ' . $order->delivery['city'] . '
CEP: ' . $order->delivery['postcode'] . '
Estado: ' . $order->delivery['state'] . '
Pas: ' . $order->delivery['country']['title'] . '

[Erros]
Erro: '.$erro.'
Mensagem: '.$msgerro.'

[Retorno dos Correios]
'.print_r($xmlobj,true).'

[Dados da Sesso]
'.print_r($_SESSION,true).'

[Dados do Servidor]
'.print_r($_SERVER,true);

    	$html_msg['EMAIL_SUBJECT'] = $email_subject;
    	$html_msg['EMAIL_MESSAGE_HTML']  = nl2br($email_text);

    	zen_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, $email_subject, $email_text, STORE_NAME, EMAIL_FROM, $html_msg, 'default');
    }
    else if (MODULE_SHIPPING_PAC_DEBUG_MODE == 'Sim, todos os clculos')
    {
    	$email_subject = 'Clculo no Mdulo de Frete dos Correios Efetuado';
  		$email_text = date('d/m/y H:i:s').'
Voc est recebendo este e-mail, pois solicitou que todas as vezes que fosse efetuado um clculo (independente de ser erro ou no), o mesmo fosse enviado pra voc.
Para desativar, acesse o painel de administrao v at a opo de mdulos de frete e mude a opo debug para no.

[Dados do Cliente]
IP: ' . $_SESSION['customers_ip_address'] . '
ID: ' . $_SESSION['customer_id'] . '
Nome: ' . $_SESSION['customer_first_name'] . ' ' . $_SESSION['customer_last_name'] . '

[Dados de Entrega]
Nome: ' . $order->delivery['firstname'] . ' ' . $order->delivery['lastname'] . '
Empresa: ' . $order->delivery['company'] . '
Logradouro: ' . $order->delivery['street_address'] . '
Bairro: ' . $order->delivery['suburb'] . '
Cidade: ' . $order->delivery['city'] . '
CEP: ' . $order->delivery['postcode'] . '
Estado: ' . $order->delivery['state'] . '
Pas: ' . $order->delivery['country']['title'] . '


[Retorno dos Correios]
'.print_r($xmlobj,true).'

[Dados da Sesso]
'.print_r($_SESSION,true).'

[Dados do Servidor]
'.print_r($_SERVER,true);

    	$html_msg['EMAIL_SUBJECT'] = $email_subject;
    	$html_msg['EMAIL_MESSAGE_HTML']  = nl2br($email_text);

    	zen_mail(STORE_OWNER, STORE_OWNER_EMAIL_ADDRESS, $email_subject, $email_text, STORE_NAME, EMAIL_FROM, $html_msg, 'default');
    }

  	return $methods;
  }
}
